@@ -15,7 +15,9 @@ import aws_cdk.aws_ssm._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("eks-spot-blocks", "0.0.0", __name__[0:-6], "eks-spot-blocks@0.0.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "eks-spot-blocks", "0.2.4", __name__[0:-6], "eks-spot-blocks@0.2.4.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
